/*
 *  Licensed to the Apache Software Foundation (ASF) under one or more
 *  contributor license agreements.  See the NOTICE file distributed with
 *  this work for additional information regarding copyright ownership.
 *  The ASF licenses this file to You under the Apache License, Version 2.0
 *  (the "License"); you may not use this file except in compliance with
 *  the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
/**
 * @author Igor V. Stolyarov
 * @version $Revision$
 */

package java.awt;

import java.awt.image.ColorModel;

/**
 * The Composite interface allows the methods to compose a draw primitive on the
 * graphics area. The classes implementing this interface provides the rules and
 * a method to create the context for a particular operation.
 * 
 * @since Android 1.0
 */
public interface Composite {

    /**
     * Creates a CompositeContext which defines the encapsulated and optimized
     * environment for a compositing operation. Several contexts can exist for a
     * single Composite object.
     * 
     * @param srcColorModel
     *            the source's ColorModel.
     * @param dstColorModel
     *            the destination's ColorModel.
     * @param hints
     *            the RenderingHints.
     * @return the CompositeContext object.
     */
    public CompositeContext createContext(ColorModel srcColorModel, ColorModel dstColorModel,
            RenderingHints hints);

}
